@@ -8,12 +8,14 @@ import jsii
 import jsii.compat
 import publication
 
+import aws_cdk.aws_certificatemanager
 import aws_cdk.aws_iam
 import aws_cdk.aws_lambda
 import aws_cdk.core
+import aws_cdk.custom_resources
 import constructs
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-cognito", "1.34.1", __name__[0:-6], "aws-cognito@1.34.1.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-cognito", "1.36.0", __name__[0:-6], "aws-cognito@1.36.0.jsii.tgz")
 
 __all__ = [
     "__jsii_assembly__",
